@@ -175,3 +175,21 @@ def operator_check(left_argument, right_argument, show_failed=False):
     if show_failed:
         returned_dictionary['failed'] = failed
     return returned_dictionary
+
+
+extended_builtins = ['Ellipsis', 'False', 'None', 'NotImplemented', 'True', 'abs', 'all', 'any',
+                     'ascii', 'bin', 'bool', 'breakpoint', 'bytearray', 'bytes', 'callable', 'chr',
+                     'classmethod', 'compile', 'complex', 'copyright', 'credits', 'delattr', 'dict',
+                     'dir', 'display', 'divmod', 'dreload', 'enumerate', 'eval', 'exec', 'execfile',
+                     'filter', 'float', 'format', 'frozenset', 'getattr', 'globals', 'hasattr',
+                     'hash', 'help', 'hex', 'id', 'input', 'int', 'isinstance', 'issubclass',
+                     'iter', 'len', 'license', 'list', 'locals', 'map', 'max', 'memoryview', 'min',
+                     'next', 'object', 'oct', 'open', 'ord', 'pow', 'print', 'property', 'range',
+                     'repr', 'reversed', 'round', 'runfile', 'set', 'setattr', 'slice', 'sorted',
+                     'staticmethod', 'str', 'sum', 'super', 'tuple', 'type', 'vars', 'zip',
+                     "(iter(b''))", '(iter(bytearray()))', '(iter({}.keys()))',
+                     '(iter({}.values()))', '(iter({}.items()))', '(iter([]))',
+                     '(iter(reversed([])))', '(iter(range(0)))', '(iter(set()))', "(iter(''))",
+                     '(iter(()))', '(iter(zip()))', '(lambda x: 1).__code__.co_lines',
+                     '(lambda x: 1).__code__.co_positions', '(type.__dict__)',
+                     '((lambda: (yield))())', 'dict().keys', 'dict().values', 'dict().items']
